@@ -2,10 +2,6 @@ class AlembicUtilsException(Exception):
     """Base exception for AlembicUtils package"""
 
 
-class DuplicateRegistration(AlembicUtilsException):
-    """An entity was registered multiple times"""
-
-
 class SQLParseFailure(AlembicUtilsException):
     """An entity could not be parsed"""
 
