@@ -19,6 +19,7 @@ ALEMBIC_COMMAND_MAP: Dict[str, Callable[..., NoReturn]] = {
     "downgrade": alem_command.downgrade,
     "revision": alem_command.revision,
     "current": alem_command.current,
+    "check": alem_command.check,
 }
 
 
@@ -27,8 +28,10 @@ def build_alembic_config(engine: Engine) -> Config:
     path_to_alembic_ini = REPO_ROOT / "alembic.ini"
 
     alembic_cfg = Config(path_to_alembic_ini)
+
     # Make double sure alembic references the test database
-    alembic_cfg.set_main_option("sqlalchemy.url", str(engine.url))
+    alembic_cfg.set_main_option("sqlalchemy.url", engine.url.render_as_string(hide_password=False))
+
     alembic_cfg.set_main_option("script_location", str((Path("src") / "test" / "alembic_config")))
     return alembic_cfg
 
